==> codemirror-language-client-0.5.0.tgz: package/playground/webpack.config.js <==
//@ts-check
/** @typedef {import('webpack').Configuration} WebpackConfig **/

'use strict';

const path = require('path');
const { DefinePlugin } = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const { default: TsconfigPathsPlugin } = require('tsconfig-paths-webpack-plugin');
const { ThemeLiquidDocsManager } = require('@shopify/theme-check-docs-updater');

/** @type {() => Promise<WebpackConfig>} */
const config = async () => {
  const docsManager = new ThemeLiquidDocsManager();
  const [tags, filters, objects, systemTranslations, sectionSchema, translationsSchema] = await Promise.all([
    docsManager.tags(),
    docsManager.filters(),
    docsManager.objects(),
    docsManager.systemTranslations(),
    docsManager.sectionSchema(),
    docsManager.translationSchema(),
  ]);

  const devServerConfig = {
    devServer: {
      open: false,
      devMiddleware: {
        writeToDisk: true,
      },
    }
  }

  return {
    ...devServerConfig,
    context: __dirname,
    mode: 'development',
    entry: './src/playground.ts',
    output: {
      path: path.join(path.resolve(__dirname), 'dist'),
      filename: '[name].bundle.js',
      clean: true,
    },
    plugins: [
      new DefinePlugin({
        WEBPACK_TAGS: JSON.stringify(tags),
        WEBPACK_FILTERS: JSON.stringify(filters),
        WEBPACK_OBJECTS: JSON.stringify(objects),
        WEBPACK_SYSTEM_TRANSLATIONS: JSON.stringify(systemTranslations),
        WEBPACK_SECTION_SCHEMA: JSON.stringify(sectionSchema),
        WEBPACK_TRANSLATIONS_SCHEMA: JSON.stringify(translationsSchema),
      }),
      new HtmlWebpackPlugin({
        title: 'Output Management',
        template: path.join(path.resolve(__dirname), 'src/index.html'),
      }),
    ],
    module: {
      rules: [
        {
          test: /\.css$/i,
          use: ['style-loader', 'css-loader'],
        },
        {
          test: /\.tsx?$/,
          use: {
            loader: 'ts-loader',
            options: {
              projectReferences: true,
            },
          },
          exclude: /node_modules/,
        },
      ],
    },
    resolve: {
      extensions: ['.tsx', '.ts', '.js'],
      plugins: [new TsconfigPathsPlugin({})],
    },
    devtool: 'source-map',
    infrastructureLogging: {
      level: 'log', // enables logging required for problem matchers
    },
  };
};

module.exports = [config];

==> codemirror-language-client-0.6.0.tgz: package/playground/webpack.config.js <==
//@ts-check
/** @typedef {import('webpack').Configuration} WebpackConfig **/

'use strict';

const path = require('path');
const { DefinePlugin } = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const { default: TsconfigPathsPlugin } = require('tsconfig-paths-webpack-plugin');
const { ThemeLiquidDocsManager } = require('@shopify/theme-check-docs-updater');

/** @type {() => Promise<WebpackConfig>} */
const config = async () => {
  const docsManager = new ThemeLiquidDocsManager();
  const [tags, filters, objects, systemTranslations, schemas] = await Promise.all([
    docsManager.tags(),
    docsManager.filters(),
    docsManager.objects(),
    docsManager.systemTranslations(),
    docsManager.schemas('theme'),
  ]);

  const devServerConfig = {
    devServer: {
      open: false,
      devMiddleware: {
        writeToDisk: true,
      },
    },
  };

  return {
    ...devServerConfig,
    context: __dirname,
    mode: 'development',
    entry: './src/playground.ts',
    output: {
      path: path.join(path.resolve(__dirname), 'dist'),
      filename: '[name].bundle.js',
      clean: true,
    },
    plugins: [
      new DefinePlugin({
        WEBPACK_TAGS: JSON.stringify(tags),
        WEBPACK_FILTERS: JSON.stringify(filters),
        WEBPACK_OBJECTS: JSON.stringify(objects),
        WEBPACK_SYSTEM_TRANSLATIONS: JSON.stringify(systemTranslations),
        WEBPACK_SCHEMAS: JSON.stringify(schemas),
      }),
      new HtmlWebpackPlugin({
        title: 'Output Management',
        template: path.join(path.resolve(__dirname), 'src/index.html'),
      }),
    ],
    module: {
      rules: [
        {
          test: /\.css$/i,
          use: ['style-loader', 'css-loader'],
        },
        {
          test: /\.tsx?$/,
          use: {
            loader: 'ts-loader',
            options: {
              projectReferences: true,
            },
          },
          exclude: /node_modules/,
        },
      ],
    },
    resolve: {
      extensions: ['.tsx', '.ts', '.js'],
      plugins: [new TsconfigPathsPlugin({})],
    },
    devtool: 'source-map',
    infrastructureLogging: {
      level: 'log', // enables logging required for problem matchers
    },
  };
};

module.exports = [config];
